@@ -49,11 +49,11 @@ class IReferenceTarget(zope.interface.Interface):
 class IReferenceManager(zope.interface.Interface):
     """Utility for managing references."""
 
-    def register_reference(target):
-        """Register a new reference to the given target."""
+    def register_reference(target, count=1):
+        """Register new references to the given target."""
 
-    def unregister_reference(target):
-        """Register that a reference to the given target was removed."""
+    def unregister_reference(target, count=1):
+        """Register that references to the given target were removed."""
 
     def is_referenced(target):
         """Tell whether the given target is being referenced."""
